rekha.plots.BarPlot
===================

.. currentmodule:: rekha.plots

.. autoclass:: BarPlot

   
   
   .. rubric:: Methods

   .. autosummary::
   
      ~BarPlot.add_annotation
      ~BarPlot.get_axes
      ~BarPlot.save
      ~BarPlot.save_all_formats
      ~BarPlot.show
      ~BarPlot.show_legend
      ~BarPlot.update_layout
   
   

   
   
   